<?php
/**
 *
 * Opt-In Cookie Manager. An extension for the phpBB Forum Software package.
 *
 * @copyright (c) 2022, Chris1278
 * @license GNU General Public License, version 2 (GPL-2.0)
 *
 */

namespace chris1278\metainfo\controller;

class admin_controller
{
	protected $extension_manager;
	protected $path_helper;
	protected $config;
	protected $language;
	protected $log;
	protected $request;
	protected $template;
	protected $user;
	protected $php_ext;
	protected $u_action;

	public function __construct(
		\phpbb\extension\manager $ext_manager,
		\phpbb\path_helper $path_helper,
		\phpbb\config\config $config,
		\phpbb\language\language $language,
		\phpbb\log\log $log,
		\phpbb\request\request $request,
		\phpbb\template\template $template,
		\phpbb\user $user,
		$php_ext
	)
	{
		$this->md_manager 			= $ext_manager->create_extension_metadata_manager('chris1278/metainfo');
		$this->admin_path 			= $path_helper->get_phpbb_root_path() . $path_helper->get_adm_relative_path();
		$this->config				= $config;
		$this->language				= $language;
		$this->log					= $log;
		$this->request				= $request;
		$this->template				= $template;
		$this->user					= $user;
		$this->php_ext				= $php_ext;
		$this->ext_display_ver 		= $this->md_manager->get_metadata('version');
		$this->ext_display_name 	= $this->md_manager->get_metadata('display-name');
		$this->ext_lang_min_ver		= $this->md_manager->get_metadata()['extra']['lang-min-ver'];
		$this->lang_ver				= ($this->language->lang('METAINFO_LANG_EXT_VER') !== 'METAINFO_LANG_EXT_VER') ? $this->language->lang('METAINFO_LANG_EXT_VER') : '0.0.0';
		$this->notes 				= '';
	}

	public function display_overview()
	{
		$this->language->add_lang('acp_metainfo_overview', 'chris1278/metainfo');
		add_form_key('metainfo_overview');
		$errors = [];

		if ($this->request->is_set_post('submit'))
		{
			if (!check_form_key('metainfo_overview'))
			{
				$errors[] = $this->language->lang('FORM_INVALID');
			}

			if (empty($errors))
			{
				$this->config->set('cmi_ov_fav_enable'								, $this->request->variable('cmi_ov_fav_enable', 0));
				$this->log->add('admin', $this->user->data['user_id'], $this->user->ip, 'LOG_ACP_METAINFO_OVERVIEW');
				trigger_error($this->language->lang('METAINFO_UPDATE') . adm_back_link($this->u_action));
			}
		}

		$s_errors = !empty($errors);

		if (!phpbb_version_compare($this->lang_ver, $this->ext_lang_min_ver, '>='))
		{
			$this->add_note($this->notes, $this->language->lang('CM_MSG_LANGUAGEPACK_OUTDATED'));
		}

		$this->template->assign_vars([
			'S_ERROR'										=> $s_errors,
			'ERROR_MSG'										=> $s_errors ? implode('<br />', $errors) : '',
			'METAINFO_EXT_NAME'								=> $this->ext_display_name,
			'METAINFO_EXT_VER'								=> $this->ext_display_ver,
			'METAINFO_NOTES'								=> $this->notes,
			'CMI_SITENAME'									=> $this->config['sitename'],
			'CMI_FAV_ENABLE'								=> $this->config['cmi_fav_enable'],
			'CMI_OV_FAV_ENABLE'								=> $this->config['cmi_ov_fav_enable'],
			'U_ACTION'									=>	$this->u_action,

		]);
	}

	public function display_settings()
	{
		$this->language->add_lang('acp_metainfo_settings', 'chris1278/metainfo');
		add_form_key('metainfo_settings');
		$errors = [];

		if ($this->request->is_set_post('submit'))
		{

			if (!check_form_key('metainfo_settings'))
			{
				$errors[] = $this->language->lang('FORM_INVALID');
			}

			if (empty($errors))
			{
				$this->config->set('site_desc'									, $this->request->variable('cmi_site_desc', '', true));
				$this->config->set('sitename'									, $this->request->variable('cmi_sitename', '', true));
				$this->config->set('cmi_meta_description'						, $this->request->variable('cmi_meta_description', '', true));
				$this->config->set('cmi_meta_keywords'							, $this->request->variable('cmi_meta_keywords', '', true));
				$this->config->set('cmi_meta_google_site_verification_enable'	, $this->request->variable('cmi_meta_google_site_verification_enable', 0));
				$this->config->set('cmi_meta_google_site_verification'			, $this->request->variable('cmi_meta_google_site_verification', '', true));
				$this->config->set('cmi_meta_open_graph_enable'					, $this->request->variable('cmi_meta_open_graph_enable', 0));
				$this->config->set('cmi_meta_og_url'							, $this->request->variable('cmi_meta_og_url', 0));
				$this->config->set('cmi_meta_og_description'					, $this->request->variable('cmi_meta_og_description', '', true));
				$this->config->set('cmi_meta_og_locale'							, $this->request->variable('cmi_meta_og_locale', ''));
				$this->config->set('cmi_fa_appid_enable'						, $this->request->variable('cmi_fa_appid_enable', 0));
				$this->config->set('cmi_fa_appid'								, $this->request->variable('cmi_fa_appid', '', true));
				$this->config->set('cmi_favicon_enable'							, $this->request->variable('cmi_favicon_enable', 0));
				$this->log->add('admin', $this->user->data['user_id'], $this->user->ip, 'LOG_ACP_METAINFO_SETTINGS');
				trigger_error($this->language->lang('METAINFO_UPDATE') . adm_back_link($this->u_action));
			}
		}

		$s_errors = !empty($errors);

		$this->template->assign_vars([
			'S_ERROR'										=> $s_errors,
			'ERROR_MSG'										=> $s_errors ? implode('<br />', $errors) : '',
			'METAINFO_EXT_NAME'								=> $this->ext_display_name,
			'METAINFO_EXT_VER'								=> $this->ext_display_ver,
			'CMI_SITE_DESC'									=> $this->config['site_desc'],
			'CMI_SITENAME'									=> $this->config['sitename'],
			'CMI_META_DESCRIPTION'							=> $this->config['cmi_meta_description'],
			'CMI_META_KEYWORDS'								=> $this->config['cmi_meta_keywords'],
			'CMI_META_GOOGLE_SITE_VERIFICATION_ENABLE'		=> $this->config['cmi_meta_google_site_verification_enable'],
			'CMI_META_GOOGLE_SITE_VERIFICATION'				=> $this->config['cmi_meta_google_site_verification'],
			'CMI_META_OPEN_GRAPH_ENABLE'					=> $this->config['cmi_meta_open_graph_enable'],
			'CMI_META_OG_URL'								=> $this->config['cmi_meta_og_url'],
			'CMI_META_OG_DESCRIPTION'						=> $this->config['cmi_meta_og_description'],
			'CMI_META_OG_LOCALE'							=> $this->config['cmi_meta_og_locale'],
			'CMI_FA_APPID_ENABLE'							=> $this->config['cmi_fa_appid_enable'],
			'CMI_FA_APPID'									=> $this->config['cmi_fa_appid'],
			'CMI_FAVICON_ENABLE'							=> $this->config['cmi_favicon_enable'],
			'U_BORD_META'									=> append_sid("{$this->admin_path}index.$this->php_ext" ,'i=acp_board&mode=settings'),
			'U_ACTION'										=> $this->u_action,
		]);
	}

	private function add_note(string &$notes, $msg)
	{
		$this->notes .= (($this->notes != '') ? "\n" : "") . sprintf('<p>%s</p>', $msg);

	}

	public function set_page_url($u_action)
	{
		$this->u_action = $u_action;
	}
}
